Writing your own Exercises
::::::::::::::::::::::::::

.. toctree::
    :maxdepth: 2

    theExerciseBank.rst
    multipleChoice.rst
    parsons.rst
    advancedRunestone.rst
    ExerciseAddAProblem.rst
    Exercises.rst
